==> Gateway-5.5-sources.jar: org/piangles/gateway/requests/ResponseSender.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
 
 
 
package org.piangles.gateway.requests;

import org.piangles.backbone.services.Locator;
import org.piangles.backbone.services.logging.LoggingService;
import org.piangles.gateway.Message;
import org.piangles.gateway.MessageType;
import org.piangles.gateway.client.ClientDetails;
import org.piangles.gateway.requests.dto.Response;

public final class ResponseSender
{	
	private static LoggingService logger = Locator.getInstance().getLoggingService();
	
	public static void sendResponse(ClientDetails clientDetails, Response response)
	{
		if (response.isRequestSuccessful())
		{
			logger.info("Request was processed successfully.");
		}
		else
		{
			logger.warn("Request could not be processed successfully because of : " + response.getErrorMessage());
		}
		
		try
		{
			clientDetails.getClientEndpoint().sendMessage(new Message(MessageType.Response, response));
			logger.info("Response sent to client successfully.");
		}
		catch (Exception e)
		{
			logger.error("Unable to send client response because of : ", e);
		}
	}
}

==> Gateway-8.3-sources.jar: org/piangles/gateway/requests/ResponseSender.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
 
 
 
package org.piangles.gateway.requests;

import org.piangles.backbone.services.Locator;
import org.piangles.backbone.services.logging.LoggingService;
import org.piangles.gateway.Message;
import org.piangles.gateway.MessageType;
import org.piangles.gateway.client.ClientDetails;
import org.piangles.gateway.requests.dto.Response;

public final class ResponseSender
{	
	private static LoggingService logger = Locator.getInstance().getLoggingService();
	
	public static void sendResponse(ClientDetails clientDetails, Response response)
	{
		if (!Endpoints.Ping.name().equals(response.getEndpoint()))
		{
			if (response.isRequestSuccessful())
			{
				logger.info("Request was processed successfully.");
			}
			else
			{
				logger.warn("Request could not be processed successfully because of : " + response.getErrorMessage());
			}
		}
		
		try
		{
			clientDetails.getClientEndpoint().sendMessage(new Message(MessageType.Response, response));
			if (!Endpoints.Ping.name().equals(response.getEndpoint()))
			{
				logger.info("Response sent to client successfully.");
			}
		}
		catch (Exception e)
		{
			logger.error("Unable to send client response because of : ", e);
		}
	}
}
